.. _api:

shodan
======

.. module:: shodan

.. autoclass:: Shodan
	:inherited-members:

	.. autoclass:: shodan::Shodan.Exploits
		:inherited-members:

	.. autoclass:: shodan::Shodan.Stream
		:inherited-members:

Exceptions
~~~~~~~~~~

.. autoexception:: shodan.APIError